"angleGauge" Object Construction in Package
sampSurfThere is currently only one method based on the
angleGauge generic that is used for object
construction. It is detailed below.
signature(baf = "numeric")This method takes the basal area factor as the key argument…
usage…
angleGauge(baf,
units = 'metric',
description = 'angle gauge method',
...) baf: The basal area factor.
units: Either “English” or “metric”.
description: A character vector description of the
object.