"antitheticICHSIZ"This class holds the inclusion zone definition for the antithetic importance sampling variant/protocol of critical height sampling for standing trees.
Objects can be created by calls of the
form new("antitheticICHSIZ", ...). However, this is not
recommended because the objects are fairly complex. Instead, one can use
the object constructor "antitheticICHSIZ" to create new
objects.
This class is a subclass of “importanceCHSIZ” (see below). It adds no new slots to the definition of that class, so please refer to it for the slot definitions.
Class "'>importanceCHSIZ", directly.
Class "'>criticalHeightIZ", by class "importanceCHSIZ", distance 2.
Class "'>horizontalPointIZ", by class "importanceCHSIZ", distance 3.
Class "'>circularPlotIZ", by class "importanceCHSIZ", distance 4.
Class "'>standingTreeIZ", by class "importanceCHSIZ", distance 5.
Class "'>InclusionZone", by class "importanceCHSIZ", distance 6.
signature(izObject = "antitheticICHSIZ", tract =
"Tract"): “InclusionZoneGrid” constructor
T. B. Lynch and J. H. Gove. 2013. An antithetic variate to facilitate upper-stem height measurements for critical height sampling and fixed-radius plot sampling with importance sampling. Canadian Journal of Forest Research (forthcoming).
“The InclusionZone Class” vignette.
See also the "'>circularPlotIZ",
"'>horizontalPointIZ",
"'>criticalHeightIZ",
"'>importanceCHSIZ" and
"'>pairedAICHSIZ" classes, and the
"'>standingTreeIZs" container class
# NOT RUN {
showClass("antitheticICHSIZ")
# }
Run the code above in your browser using DataLab