There is currently only one method based on the
distanceLimited generic that is used for object
construction. It is detailed below.
signature(distanceLimit = "numeric")This method takes distance limit in appropriate units as the signature argument along with other optional aruments described as follows…
usage…
distanceLimited(distanceLimit,
units = 'metric',
description = 'distance limited method',
...) distanceLimit: The distance limit in appropriate
units (feet or meters).
units: Either “English” or “metric”.
description: A character vector description of the
object.