Objects can be created by calls of the
form new("downLogIZs", ...); however, as in the other classes
within this package, constructors have been written to simplify the
process. A downLogIZs constructor should therefore be used
in preference to new. The constructor, downLogIZs,
has different forms that will be useful with different classes of objects.