The following are the constructor methods for class
“'>downLogIZs” in Package `sampSurf'. Please
see “The InclusionZone Class” vignette for more
information and examples on the usage of these methods, as well as the
downLogIZs generic and class
'>downLogIZs.
signature(object = "list")This method will create a container object out of a list containing
"'>downLogIZ" objects.
usage…
downLogIZs(object,
description = '',
... )object: A list object containing the collection of
inclusion zones for a given subclass of
"'>downLogIZ". Note that the list must
contain objects that are all of the same class, or sampling
method.
description: A description of the collection.
... : Other arguments to be passed along (not used currently).
signature(object = "downLogs")Create a container object out of a
"'>downLogs" container object and an
"'>InclusionZone" subclass specification.
usage…
downLogIZs(object,
iZone,
description = '',
... )