fullChainSawIZ” object construction in Package
sampSurfThe one constructor method that is available for creating valid
objects of class "'>fullChainSawIZ" is
documented below. Note that because the inclusion zone for
this method is exactly the same as that for the
"'>sausageIZ" class (sausage sampling), the same
arguments are used here as in that constructor.
signature(downLog = "downLog", plotRadius = "numeric")usage…
fullChainSawIZ(downLog,
plotRadius,
nptsHalfCircle = 50,
description = 'Inclusion zone for "fullChainSaw" sampling method',
spID = paste('fcs', .StemEnv$randomID(), sep=':'),
spUnits = CRS(projargs = as.character(NA)),
... )downLog: An object of class
"'>downLog" which the inclusion zone is to be
determined for under this method.
plotRadius: The radius of the circular fixed-area
plot in the correct units: feet for "English" and meters for
"metric."
nptsHalfCircle: The number of points to use in the
half-circle at each end of the sausage-shaped inclusion zone for
the polygon representation of the object.
description: A character vector description of the
object.
spID: A unique identifier that will be used in
displaying the spatial polygon component of the object.
spUnits: A valid CRS object
specifying the Coordinate Reference System. This defaults to
NA, which means you want to use your own user-defined
system, say for a sample plot located in the field.
dots: Arguments to be passed on.